@@ -134,9 +134,7 @@ class ALIGNNConv(nn.Module):
     """Line graph update."""
 
     def __init__(
-        self,
-        in_features: int,
-        out_features: int,
+        self, in_features: int, out_features: int,
     ):
         """Set up ALIGNN parameters."""
         super().__init__()
@@ -203,19 +201,13 @@ class ALIGNN(nn.Module):
         )
 
         self.edge_embedding = nn.Sequential(
-            RBFExpansion(
-                vmin=0,
-                vmax=8.0,
-                bins=config.edge_input_features,
-            ),
+            RBFExpansion(vmin=0, vmax=8.0, bins=config.edge_input_features,),
             MLPLayer(config.edge_input_features, config.embedding_features),
             MLPLayer(config.embedding_features, config.hidden_features),
         )
         self.angle_embedding = nn.Sequential(
             RBFExpansion(
-                vmin=-1,
-                vmax=1.0,
-                bins=config.triplet_input_features,
+                vmin=-1, vmax=1.0, bins=config.triplet_input_features,
             ),
             MLPLayer(config.triplet_input_features, config.embedding_features),
             MLPLayer(config.embedding_features, config.hidden_features),
@@ -223,10 +215,7 @@ class ALIGNN(nn.Module):
 
         self.alignn_layers = nn.ModuleList(
             [
-                ALIGNNConv(
-                    config.hidden_features,
-                    config.hidden_features,
-                )
+                ALIGNNConv(config.hidden_features, config.hidden_features,)
                 for idx in range(config.alignn_layers)
             ]
         )
